==> thirdparty-service-biz-1.0.33.p2-20211015.034711-1-sources.jar: cn/com/duiba/tool/zhiji/ZhiJiParamTool.java <==
package cn.com.duiba.tool.zhiji;

import cn.com.duiba.boot.utils.SpringEnvironmentUtils;
import com.alibaba.fastjson.JSON;
import com.google.common.collect.Maps;
import org.apache.commons.codec.binary.Hex;
import org.apache.commons.lang.StringUtils;
import org.apache.commons.lang3.RandomUtils;
import org.apache.http.client.config.RequestConfig;
import org.apache.http.client.methods.HttpGet;
import org.apache.http.client.methods.HttpPost;
import org.apache.http.entity.StringEntity;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import javax.crypto.Mac;
import javax.crypto.SecretKey;
import javax.crypto.spec.SecretKeySpec;
import java.io.UnsupportedEncodingException;
import java.lang.reflect.Field;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;

/**
 * @author: pengyi
 * @description: 智己参数构建解析工具
 * @date: 2021/9/1 下午4:30
 */
public class ZhiJiParamTool {

    private final static Logger log = LoggerFactory.getLogger(ZhiJiParamTool.class);

    private static final String MAC_NAME = "HmacSHA256";
    private static final String ENCODING = "UTF-8";
    private static final String TEST_ENCRYPT_KEY = "myi6MBoU8PSIXnrkC6nogKKd1yM9x1Q8";
    private static final String PROD_ENCRYPT_KEY = "dF0Watf8GszMNpsJ4jC3YG4JBxK9A7Qu";

    private static final RequestConfig requestConfig;
    private static final int FIVE_SECONDS = 5*1000;
    private static final int TEN_SECONDS = 10*1000;

    static {
        //http请求超时配置
        requestConfig = RequestConfig.custom().setConnectTimeout(FIVE_SECONDS).setSocketTimeout(TEN_SECONDS).setConnectionRequestTimeout(500).build();
    }
    /**
     * 构建参数，创建httpPost请求
     * dto只能是对象，不能是map
     * @param dto
     * @return
     */
    public static HttpPost createHttpPost(Object dto, String url) {
        if (dto == null || StringUtils.isBlank(url)) {
            return null;
        }
        log.info("智己-post请求参数，url:{}, params:{}", url, JSON.toJSONString(dto));
        HttpPost httpPost = new HttpPost(url);
        byte[] bytes = hmacEncrypt(JSON.toJSONString(dto));
        if (bytes == null) {
            log.warn("智己-发送请求，参数加密失败，url:{}, param:{}", url, JSON.toJSONString(dto));
            return null;
        }
        String signature = Hex.encodeHexString(bytes);
        httpPost.setHeader("signature", signature);
        httpPost.setHeader("Content-Type","application/json");
        httpPost.setHeader("charset","gbk");
        try {
            httpPost.setEntity(new StringEntity(JSON.toJSONString(dto)));
        } catch (UnsupportedEncodingException e) {
            log.warn("智己-发送请求，post参数，url:{}, param:{}", url, JSON.toJSONString(dto));
            return null;
        }
        httpPost.setConfig(requestConfig);
        log.info("智己-post请求参数，params:{},signature:{},header:{}",JSON.toJSONString(dto),signature, JSON.toJSONString(httpPost.getAllHeaders()));
        return httpPost;
    }

    /**
     * 构建参数，创建httpGet请求
     * @param params
     * @return
     */
    public static HttpGet createHttpGet(Map<String,String> params, String url) {
        if (params == null || StringUtils.isBlank(url)) {
            return null;
        }
        log.info("智己-get请求参数，url:{}, params:{}", url, JSON.toJSONString(params));
        byte[] bytes = hmacEncrypt(JSON.toJSONString(params));
        if (bytes == null) {
            log.warn("智己-发送请求，参数加密失败，url:{}, param:{}", url, JSON.toJSONString(params));
            return null;
        }
        StringBuilder param = new StringBuilder(url).append("?");
        List<String> paramList = new ArrayList<>();
        params.entrySet().forEach(entry -> {
            paramList.add(entry.getKey()+"="+entry.getValue());
        });
        param.append(StringUtils.join(paramList,"&"));
        HttpGet httpGet = new HttpGet(param.toString());
        String signature = Hex.encodeHexString(bytes);
        httpGet.setHeader("signature", signature);
        httpGet.setHeader("Content-Type","application/json");
        httpGet.setHeader("charset","gbk");
        log.info("智己-get请求参数，url:{},signature:{},header:{}", param.toString(), signature, JSON.toJSONString(httpGet.getAllHeaders()));
        httpGet.setConfig(requestConfig);
        return httpGet;
    }

    /**
     * dto类转位map
     * 不为空的字段会放入map中
     * @param obj
     * @return
     * @throws IllegalAccessException
     */
    public static Map<String, String> dtoConvertParams(Object obj) throws IllegalAccessException {
        if (obj == null) {
            return null;
        }
        Map<String, String> params = Maps.newHashMap();
        Class clazz = obj.getClass();
        Field[] fields = clazz.getDeclaredFields();
        for (Field field : fields) {
            field.setAccessible(true);
            if (field.get(obj) != null) {
                params.put(field.getName(), String.valueOf(field.get(obj)));
            }
        }
        return params;
    }

    /**
     * hamc加密
     * 加密后byte[]需用Hex.encodeHexString(bytes)转为string
     * @param encryptText
     * @return
     */
    public static byte[] hmacEncrypt(String encryptText) {
        String encryptKey = TEST_ENCRYPT_KEY;
        if (SpringEnvironmentUtils.isProdEnv() || SpringEnvironmentUtils.isPreEnv()) {
            encryptKey = PROD_ENCRYPT_KEY;
        }
        try {
            byte[] data = encryptKey.getBytes(ENCODING);
            //根据给定的字节数组构造一个密钥,第二参数指定一个密钥算法的名称
            SecretKey secretKey = new SecretKeySpec(data, MAC_NAME);
            //生成一个指定 Mac 算法 的 Mac 对象
            Mac mac = Mac.getInstance(MAC_NAME);
            //用给定密钥初始化 Mac 对象
            mac.init(secretKey);
            byte[] text = encryptText.getBytes(ENCODING);
            //完成 Mac 操作
            return mac.doFinal(text);
        } catch (Exception e) {
            log.error("智己-hmac加密失败，encryptText：{}", encryptText, e);
        }
        return null;
    }

    /**
     * 返回6位随机数字
     * @return
     */
    public static String generateRandom() {
        return String.valueOf(RandomUtils.nextInt(100000,999999));
    }
}

==> thirdparty-service-biz-1.0.33.1-20210906.061255-2-sources.jar: cn/com/duiba/tool/zhiji/ZhiJiParamTool.java <==
package cn.com.duiba.tool.zhiji;

import cn.com.duiba.credits.sdk.SignTool;
import com.google.common.collect.Maps;
import org.apache.commons.lang.StringUtils;
import org.apache.http.client.methods.HttpPost;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.lang.reflect.Field;
import java.util.Map;

/**
 * @author: pengyi
 * @description: 智己参数构建解析工具
 * @date: 2021/9/1 下午4:30
 */
public class ZhiJiParamTool {

    private final static Logger log = LoggerFactory.getLogger(ZhiJiParamTool.class);

    /**
     * 构建参数，创建httpPost请求
     * @param dto
     * @return
     */
    public static HttpPost createHttpRequest(Object dto, String url) {
        if (dto == null || StringUtils.isBlank(url)) {
            return null;
        }
        HttpPost httpPost = new HttpPost(url);
        try {
            Map<String, String> params = dtoConvertParams(dto);
            String sign = SignTool.sign(params);
            params.put("sign", sign);
        } catch (Exception e) {
            log.warn("智己-发送请求，参数解析失败，url:{}, param:{}", url, dto, e);
        }
        return httpPost;
    }

    /**
     * dto类转位map
     * 不为空的字段会放入map中
     * @param obj
     * @return
     * @throws IllegalAccessException
     */
    public static Map<String, String> dtoConvertParams(Object obj) throws IllegalAccessException {
        if (obj == null) {
            return null;
        }
        Map<String, String> params = Maps.newHashMap();
        Class clazz = obj.getClass();
        Field[] fields = clazz.getDeclaredFields();
        for (Field field : fields) {
            field.setAccessible(true);
            if (field.get(obj) != null) {
                params.put(field.getName(), String.valueOf(field.get(obj)));
            }
        }
        return params;
    }
}
